# Initme

Utility to help setup python projects/libraries.

## Usages

* Created an `__init__.py` file in every directory containing a python script. Examples: `python -m initme /path/to/my/project` or `cd /path/to/my/project && python -m initme`

## Install

`pip install initme --user`
